#! /usr/bin/perl

use Apache::Bio::Tools::PSort ();
use Apache::RPC::Server ();
use Apache::Registry ();
use Apache::Constants ();
use Apache ();

use strict;

my $PSORT_ROOT = "/usr/local/psort/server/conf/";
my $HMMTOP_DIR = "/path/to/HMMTOP/installation/";
my $BLAST_DIR  = "/path/to/BLAST/instalation/";

our %ENV;

MAIN: {
  my $sighmm  = "$PSORT_ROOT/analysis/signal/model.hmm";
  my $sigsvm  = "$PSORT_ROOT/analysis/signal/model.svm";
  my $sigprog = "$PSORT_ROOT/analysis/signal/check-sig";
  my $ompdb   = "$PSORT_ROOT/analysis/omp-motif/omp-motifs.txt";
  my $slmodel = "$PSORT_ROOT/analysis/subloc/subloc.svm";
  my $scldb   = "$PSORT_ROOT/analysis/sclblast/sclblast";
  my $motifdb = "$PSORT_ROOT/analysis/motif/motifs.txt";

  my $bayes   = "$PSORT_ROOT/output/bayesian/bayes.model.new";

  $ENV{BLASTDIR} = $BLAST_DIR;

  my $psort = Apache::Bio::Tools::PSort->instance();

  # Load the various modules.  (Note that the second parameter is the modules
  # "aliased" name (to allow more than one instance of a given module,
  # possibly with different params, in a pathway) and **MUST** agree with the
  # names in the Bayes model file.  **IF THEY DON'T AGREE YOUR RESULTS WILL
  # BE BUNG!**
  $psort->install('HMMTOP', 'HMMTOP', { -hmmtopdir => $HMMTOP_DIR });
  $psort->install('SCLBlast', 'SCL-BLAST', { -database => $scldb });
  $psort->install('OMPMotif', 'OMPMotif', { -database => $ompdb });
  $psort->install('Motif', 'Motif', { -database => $motifdb });
  $psort->install('SubLoc', 'SubLocC', { -model => $slmodel });
  $psort->install('Signal', 'Signal', { -svm => $sigsvm, -hmm => $sighmm,
					-program => $sigprog });
  $psort->install('Bayesian', 'Bayesian', {-model => $bayes });

  $psort->add_path("psort", "analysis", ['HMMTOP', sub { 1 },
					 ['SCL-BLAST', sub { 1 },
					  ['OMPMotif', sub { 1 },
					   ['Motif', sub { 1 },
					    ['SubLocC', sub { 1 } ,
					     ['Signal']]]]]]);
}
